aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/style/template.php
diff options
context:
space:
mode:
authorVjacheslav Trushkin <arty@phpbb.com>2012-03-14 23:12:11 +0200
committerVjacheslav Trushkin <arty@phpbb.com>2012-03-14 23:12:11 +0200
commitb7d84a586c1e253ff7075e80ab721db5c1101c9f (patch)
tree16e0e179d9f5d0382236ac4865c56e4c7cff3cac /phpBB/includes/style/template.php
parent7d414d04ca80b3dc5efc7ece4c3c28123a4e7e89 (diff)
downloadforums-b7d84a586c1e253ff7075e80ab721db5c1101c9f.tar
forums-b7d84a586c1e253ff7075e80ab721db5c1101c9f.tar.gz
forums-b7d84a586c1e253ff7075e80ab721db5c1101c9f.tar.bz2
forums-b7d84a586c1e253ff7075e80ab721db5c1101c9f.tar.xz
forums-b7d84a586c1e253ff7075e80ab721db5c1101c9f.zip
[feature/merging-style-components] Renaming template classes
Changing template classes prefixes from phpbb_template to phpbb_style (for classes that will work with styles) or phpbb_style_template (for classes that are specific to templates) PHPBB3-10632
Diffstat (limited to 'phpBB/includes/style/template.php')
-rw-r--r--phpBB/includes/style/template.php34
1 files changed, 17 insertions, 17 deletions
diff --git a/phpBB/includes/style/template.php b/phpBB/includes/style/template.php
index bac5445511..a8c5139dd0 100644
--- a/phpBB/includes/style/template.php
+++ b/phpBB/includes/style/template.php
@@ -29,10 +29,10 @@ if (!defined('IN_PHPBB'))
* Base Template class.
* @package phpBB3
*/
-class phpbb_template
+class phpbb_style_template
{
/**
- * @var phpbb_template_context Template context.
+ * @var phpbb_style_template_context Template context.
* Stores template data used during template rendering.
*/
private $context;
@@ -64,13 +64,13 @@ class phpbb_template
/**
* Template locator
- * @var phpbb_template_locator
+ * @var phpbb_style_locator
*/
private $locator;
/**
* Template path provider
- * @var phpbb_template_path_provider
+ * @var phpbb_style_path_provider
*/
private $provider;
@@ -79,10 +79,10 @@ class phpbb_template
*
* @param string $phpbb_root_path phpBB root path
* @param user $user current user
* @param phpbb_template_locator $locator template locator
* @param phpbb_template_path_provider $provider template path provider
*/
- public function __construct($phpbb_root_path, $phpEx, $config, $user, phpbb_template_locator $locator, phpbb_template_path_provider_interface $provider)
+ public function __construct($phpbb_root_path, $phpEx, $config, $user, phpbb_style_locator $locator, phpbb_style_path_provider_interface $provider)
{
$this->phpbb_root_path = $phpbb_root_path;
$this->phpEx = $phpEx;
@@ -139,7 +139,7 @@ class phpbb_template
$this->cachepath = $this->phpbb_root_path . 'cache/tpl_' . str_replace('_', '-', $template_name) . '_';
- $this->context = new phpbb_template_context();
+ $this->context = new phpbb_style_template_context();
return true;
}
@@ -298,15 +298,15 @@ class phpbb_template
* configuration setting may be used to force templates to be always
* recompiled.
*
* Returns an object implementing phpbb_template_renderer, or null
* if template loading or compilation failed. Call render() on the
* renderer to display the template. This will result in template
* contents sent to the output stream (unless, of course, output
* buffering is in effect).
*
* @param string $handle Handle of the template to load
* @return phpbb_template_renderer Template renderer object, or null on failure
* @uses phpbb_template_compile is used to compile template source
*/
private function _tpl_load($handle)
{
@@ -330,18 +330,18 @@ class phpbb_template
// Recompile page if the original template is newer, otherwise load the compiled version
if (!$recompile)
{
- return new phpbb_template_renderer_include($output_file, $this);
+ return new phpbb_style_template_renderer_include($output_file, $this);
}
- $compile = new phpbb_template_compile($this->config['tpl_allow_php']);
+ $compile = new phpbb_style_template_compile($this->config['tpl_allow_php']);
if ($compile->compile_file_to_file($source_file, $output_file) !== false)
{
- $renderer = new phpbb_template_renderer_include($output_file, $this);
+ $renderer = new phpbb_style_template_renderer_include($output_file, $this);
}
else if (($code = $compile->compile_file($source_file)) !== false)
{
- $renderer = new phpbb_template_renderer_eval($code, $this);
+ $renderer = new phpbb_style_template_renderer_eval($code, $this);
}
else
{
@@ -403,7 +403,7 @@ class phpbb_template
$this->context->append_var($varname, $varval);
}
// Docstring is copied from phpbb_template_context method with the same name.
/**
* Assign key variable pairs from an array to a specified block
* @param string $blockname Name of block to assign $vararray to
@@ -414,7 +414,7 @@ class phpbb_template
return $this->context->assign_block_vars($blockname, $vararray);
}
// Docstring is copied from phpbb_template_context method with the same name.
/**
* Change already assigned key variable pair (one-dimensional - single loop entry)
*
@@ -79,10 +79,10 @@ class phpbb_template
* @param string $phpbb_root_path phpBB root path
* @param user $user current user
- * @param phpbb_template_locator $locator template locator
- * @param phpbb_template_path_provider $provider template path provider
+ * @param phpbb_style_locator $locator template locator
+ * @param phpbb_style_path_provider $provider template path provider
*/
@@ -298,15 +298,15 @@ class phpbb_template
* recompiled.
*
- * Returns an object implementing phpbb_template_renderer, or null
+ * Returns an object implementing phpbb_style_template_renderer, or null
* if template loading or compilation failed. Call render() on the
* renderer to display the template. This will result in template
@@ -298,15 +298,15 @@ class phpbb_template
*
* @param string $handle Handle of the template to load
- * @return phpbb_template_renderer Template renderer object, or null on failure
- * @uses phpbb_template_compile is used to compile template source
+ * @return phpbb_style_template_renderer Template renderer object, or null on failure
+ * @uses phpbb_style_template_compile is used to compile template source
*/
private function _tpl_load($handle)
@@ -403,7 +403,7 @@ class phpbb_template
$this->context->append_var($varname, $varval);
}
- // Docstring is copied from phpbb_template_context method with the same name.
+ // Docstring is copied from phpbb_style_template_context method with the same name.
/**
* Assign key variable pairs from an array to a specified block
@@ -414,7 +414,7 @@ class phpbb_template
return $this->context->assign_block_vars($blockname, $vararray);
}
- // Docstring is copied from phpbb_template_context method with the same name.
+ // Docstring is copied from phpbb_style_template_context method with the same name.
/**
* Change already assigned key variable pair (one-dimensional - single loop entry)